pro sel_leak_image, item, leak_files, dsets, leak_rmap, qdebug=qdebug, $
   backup_era=backup_era
;+
;NAME:
;	sel_leak_image
;PURPOSE:
;	Select the proper leak image required for correction
;INPUT:
;	item	- Index or roadmap
;OUTPUT:
;	leak_files- The names of the leak files
;	dsets	- It is the same length as "item".  The value is -1 if 
;		  no leak image is available.
;HISTORY:
;	Written 27-Aug-93 by M.Morrison
;	13-Sep-93 (MDM) - Replaced Al.1 Oct-92 image file sfc921127.0947;			  with sfc921125.1708 (actually the same image, 
;			  the previous file had the wrong index/label).
;	15-Sep-93 (MDM) - Modified the logic so that a ND leak image
;			  is not used to correct an OPEN x-ray image.
;			- Added 5 leak images which used ND filter
;	19-Nov-93 (MDM) - Modification to not even bother checking for
;			  SFC files if data is pre-Nov-92.
;       10-Dec-94 (SLF) - major rewrite - add hook for pointing
;			  (use match_index.pro for image selection)
;                         (no explicit file names - check all matching SFC)
;        3-Jan-94 (SLF) - pre-define output for pre-Nov-1992 data
;       22-aug-95 (SLF) - check "leak era" and select appropriate image
;	19-Apr-96 (GLS) - Corrected a bug in the assignment of indices to
;			  DSETS from the values returned by MATCH_INDEX.
;			- Corrected 'No leak image' warning code
;       11-oct-96 (SLF) - add /ccdtemp switch to match_index call
;       20-Jul-98 (SLF) - add /cd to file_list (avoid 'arg list too long')
;        1-Feb-99 (SLF) - auto backup to previous era  (WARN)
;       26-feb-99 (SLF) - remove hard coded leak era start (use get_yo_dates)
;                         inhibit auto-era-backup logic 
;        1-Mar-99 (SLF) - eliminate bogus 'no leak image' for files
;                         spanning era 0 (none required) and era1 
;	16-Jan-02 (LWA) - added test for leak_index0 in common block
;
;   Common Blocks:
;      sel_leak_image	 (files & roadmaps)
;      sel_leak_image1   (index records)
;-
common sel_leak_image,   leak_files0, leak_rmap0
common sel_leak_image1,  leak_index0

if n_elements(backup_era) eq 0 then backup_era = -1
backup_era=backup_era+1

backup_enabled = 0                ; S.L.Freeland, 26-feb-99 INHIBIT auto back
                                  
;
n = n_elements(item)
dsets = intarr(n)-1  

; ---------- return immediately if no input follows first entrance filt failure
after_first=ssw_deltat(item,ref=(get_yo_dates(/ent))(1),/sec) gt 0
afterss=where(after_first,aftercnt)
if aftercnt eq 0 then return         ; *** early exit if all before first fail
; ---------------------------------------------------------
;
;   slf 9-dec-94 read index instead (pointing in history record)
;   lwa 16-Jan-02 test for BOTH leak_rmap0 and leak_index0
if (n_elements(leak_rmap0) eq 0) or (n_elements(leak_index0) eq 0) then begin
    leak_files0 = file_list('$DIR_SXT_SFC', 'sfc*',/cd)
    if (keyword_set(qdebug)) then message, 'Reading index records...', /info
    rd_roadmap, leak_files0, leak_rmap0
    rd_sda, leak_files0, -1, leak_index0, /nodata
endif
;
leak_files = leak_files0
leak_rmap  = leak_rmap0
leak_index = leak_index0

; SLF, 23-aug-1995, only match SFC records for the corresponding "leak era"
leak_ranges=[get_yo_dates(/entrance),fmt_tim(ut_time())]
sfcss=lindgen(n_elements(leak_index))

for i=1,n_elements(leak_ranges)-2  do begin
   ss=sel_timrange(item,leak_ranges(i),leak_ranges(i+1),/between)
   sss=sel_timrange(leak_rmap,leak_ranges(i-backup_era>0),leak_ranges(i+1-backup_era>0),/between)
   if ss(0) ne -1 and sss(0) ne -1 then begin
      chkss=match_index(item(ss),leak_index(sss),/point,ccdtemp=2,debug=qdebug)
      chkss_good = where(chkss ne -1,count_good)
      if count_good gt 0 then dsets(ss(chkss_good))=sss(chkss(chkss_good))
   endif
endfor

dsets_bad = where(dsets eq -1 and after_first,count_bad)

if count_bad gt 0 then begin 
   if (backup_era lt 1) and (backup_enabled) then begin           ; recurse w/previous era
      box_message,['No leak images in this era found - backup up one era!!',$
                   '(correction will improve significantly in the future)']
      sel_leak_image, item, leak_files, dsets, leak_rmap, qdebug=qdebug, $
             backup_era=backup_era 
      return   
   endif else begin 
      box_message,['Warning: No leak image match for index:', $
         get_info(item(dsets_bad),/non)]
   endelse
endif

end
